@@ -3,7 +3,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '1.70';
+our $VERSION = '1.71';
 
 use Carp;
 use Data::Compare;
@@ -447,6 +447,26 @@ sub run {
 
     return $struct;
 }
+sub rw {
+    trace() if $ENV{TRACE};
+
+    # Insert a File::Edit::Portable object into self
+
+    my ($self, $rw) = @_;
+
+    $self->{rw} = $rw if defined $rw;
+
+    return $self->{rw};
+}
+sub tempfile {
+    trace() if $ENV{TRACE};
+
+    # Insert a File::Edit::Portable::tempfile object into self
+
+    my ($self, $tempfile) = @_;
+    $self->{tempfile} = $tempfile if defined $tempfile;
+    return $self->{tempfile};
+}
 sub valid_params {
     trace() if $ENV{TRACE};
     return %{ $_[0]->{valid_params} };
@@ -609,7 +629,7 @@ sub _config {
 
     $self->{valid_params} = \%valid_params;
 
-    # get previous run's config
+    # store previous run's config
 
     %{$self->{previous_run_config}} = %{$self->{params}};
 
@@ -746,18 +766,18 @@ sub _read_file {
 
     die "Can't call method \"serialize\" on an undefined file\n" if ! -f $file;
 
-    $self->{rw} = File::Edit::Portable->new;
+    $self->rw(File::Edit::Portable->new);
 
     my $ppi_doc;
 
-    if ($self->{rw}->recsep($file, 'hex') ne $self->{rw}->platform_recsep('hex')) {
-        my $fh = $self->{rw}->read($file);
+    if ($self->rw()->recsep($file, 'hex') ne $self->rw()->platform_recsep('hex') || $ENV{ISSUE_31_TEST}) {
+        my $fh = $self->rw()->read($file);
 
-        my $tempfile = $self->{rw}->tempfile;
-        my $tempfile_name = $tempfile->filename;
-        my $platform_recsep = $self->{rw}->platform_recsep;
+        $self->tempfile($self->rw()->tempfile);
+        my $tempfile_name = $self->tempfile()->filename;
+        my $platform_recsep = $self->rw()->platform_recsep;
 
-        $self->{rw}->write(
+        $self->rw()->write(
             copy => $tempfile_name,
             contents => $fh,
             recsep => $platform_recsep
@@ -765,7 +785,8 @@ sub _read_file {
 
         $ppi_doc = PPI::Document->new($tempfile_name);
 
-        close $tempfile;
+        close $self->tempfile;
+        unlink $tempfile_name or die "Can't delete temp file $tempfile_name: $!";
     }
     else {
         $ppi_doc = PPI::Document->new($file);
@@ -773,7 +794,6 @@ sub _read_file {
 
     @{ $p->{file_contents} } = split /\n/, $ppi_doc->serialize;
 
-
     if (! $p->{file_contents}->[0]){
         return 0;
     }
@@ -791,9 +811,9 @@ sub _run_directory {
 
     my $dir = $self->{params}{file};
 
-    $self->{rw} = File::Edit::Portable->new;
+    $self->rw(File::Edit::Portable->new);
 
-    my @files = $self->{rw}->dir(
+    my @files = $self->rw()->dir(
         dir => $dir,
         maxdepth => $self->{params}{maxdepth} || 0,
         types => $self->{params}{extensions},
@@ -863,7 +883,7 @@ sub _write_file {
 
     my $write_ok = eval {
         $write_response
-          = $self->{rw}->write(file => $file, contents => $contents);
+          = $self->rw()->write(file => $file, contents => $contents);
         1;
     };
 
@@ -1259,6 +1279,14 @@ Perl files and subs.
 <a href="http://travis-ci.org/stevieb9/devel-examine-subs"><img src="https://secure.travis-ci.org/stevieb9/devel-examine-subs.png"/>
 <a href='https://coveralls.io/github/stevieb9/devel-examine-subs?branch=master'><img src='https://coveralls.io/repos/stevieb9/devel-examine-subs/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
+=head1 DESCRIPTION
+
+Gather information about subroutines in Perl files (and in-memory modules),
+with the ability to search/replace code, inject new code, get line counts,
+get start and end line numbers, access the sub's code and a myriad of other
+options.  Files are parsed using L<PPI>, not by inspecting packages or
+coderefs.
+
 =head1 SYNOPSIS
 
     use Devel::Examine::Subs;
@@ -1376,17 +1404,6 @@ Most methods can include or exclude specific subs
 
     # note that 'exclude' param renders 'include' invalid
 
-
-=head1 DESCRIPTION
-
-Gather information about subroutines in Perl files (and in-memory modules),
-with the ability to search/replace code, inject new code, get line counts,
-get start and end line numbers, access the sub's code and a myriad of other
-options.  Files are parsed using L<PPI>, not by inspecting packages or
-coderefs.
-
-
-
 =head1 METHODS
 
 See the L</PARAMETERS> for the full list of params, and which ones
@@ -1647,7 +1664,34 @@ This allows for very fine-grained interaction with the application, and makes
 it easy to write new engines and for testing.
 
 
+=head2 C<rw($rw)>
 
+Parameters:
+
+    $rw
+
+Optional, C<File::Edit::Portable> object.
+
+On first call, a L<File::Edit::Portable> object must be sent in. On subsequent
+calls, we'll return this object.
+
+Returns: C<File::Edit::Portable> object if previously sent in, else returns
+C<undef>.
+
+
+=head2 C<tempfile($file)>
+
+Parameters:
+
+    $file
+
+Optional, C<File::Temp> object, typically generated through a call to
+C<File::Edit::Portable>'s C<tempfile()>.
+
+On first call, a C<Temp::File> object must be sent in. On subsequent calls,
+we'll return that object.
+
+Returns: C<Temp::File> object if previously sent in, else returns C<undef>.
 
 
 =head2 C<add_functionality>
@@ -1963,7 +2007,6 @@ In your calling script, set C<$ENV{DES_TRACE} = 1>.
 
 See C<perldoc Devel::Trace::Subs> for information on how to access the traces.
 
-
 =head1 SEE ALSO
 
 =over 4
@@ -1982,12 +2025,6 @@ Information related to the 'engine' phase core modules.
 
 =back
 
-
-
-
-
-
-
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
@@ -2000,7 +2037,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Steve Bertrand.
+Copyright 2016-2020 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of either: the GNU General Public License as published by the
